==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/smime/language/de.php <==
<?php


$l["enterPassword"]="Geben Sie bitte das Kennwort für Ihren SMIME-Schlüssel ein.";
$l["messageEncrypted"]="Diese E-Mail wurde Ihnen verschlüsselt geschickt.";
$l["messageSigned"]="Diese E-Mail ist kryptographisch signiert. Klicken Sie hier, um die Signatur zu überprüfen und das Zertifikat zu importieren.";
$l["smimeCert"]="SMIME-Zertifikat";
$l["sign"]="Signieren mit SMIME";
$l["encrypt"]="Verschlüsseln mit SMIME";
$l["settings"]="SMIME";
$l["deleteCert"]="Zertifikat löschen";
$l["selectPkcs12Cert"]="Neues PKCS12-Zertifikat auswählen";
$l["alwaysSign"]='E-Mails immer signieren';
$l["pkcs12Cert"]="PKCS12-Zertifikat";
$l["pkcs12CertInfo"]="Um ein neues PCSK12-Zertifikat hochzuladen, müssen Sie Ihr {product_name}-Kennwort eingeben. Dieses Kennwort muß sich aufgrund von Sicherheitsrichtlinien vom PCSK12-Schlüsselkennwort unterscheiden. Ein leeres Kennwort ist ebenso nicht zugelassen.";
$l["pubCerts"]="Öffentliche SMIME-Zertifikate";
$l["youHaveAcert"]='Sie haben bereits ein Zertifikat hochgeladen. SMIME-Unterstützung ist für diesen Account aktiviert.';
$l["downloadCert"]='Zertifikat herunterladen';
$l['name']='SMIME Unterstützung';
$l['description']='Erweitert das E-Mailmodul mith SMIME-Signatur und -Verschlüsselung.';
$l['noPublicCertForEncrypt']="E-Mail kann nicht verschlüsselt werden, da Sie nicht über das öffentliche Zertifikat für %s verfügen. Öffnen Sie eine signierte E-Mail des Empfängers und überprüfen und installieren Sie das Zertifikat.";
$l['noPrivateKeyForDecrypt']="Diese E-Mail ist verschlüsselt jedoch verfügen Sie nicht über den privaten Schlüssel, um die E-Mail zu entschlüsseln.";
$l['badGoLogin']="Das {product_name}-Kennwort war nicht korrekt.";
$l['smime_pass_matches_go']="Ihr SMIME-Schlüsselkennwort entspricht Ihrem {product_name}-Kennwort. Dies widerspricht den Sicherheitsrichtlinien!";
$l['smime_pass_empty']="Ihr SMIME-Schlüssel ist nicht durch ein Kennwort geschützt. Dies widerspricht den Sicherheitsrichtlinien!";
$l['invalidCert']="Das Zertifikat ist ungültig!";
$l['validCert']="Gültiges Zertifikat";
$l['certEmailMismatch']="Gültiges Zertifikat, aber die Absenderadresse stimmt nicht mit der E-Mailadresse des Zertifikates überein.";
$l['decryptionFailed']='SMIME-Entschlüsselung dieser Nachricht fehlgeschlagen.';

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/smime/language/de.php <==
<?php


$l["enterPassword"]="Geben Sie bitte das Kennwort für Ihren SMIME-Schlüssel ein.";
$l["messageEncrypted"]="Diese E-Mail wurde Ihnen verschlüsselt geschickt.";
$l["messageSigned"]="Diese E-Mail ist kryptographisch signiert. Klicken Sie hier, um die Signatur zu überprüfen und das Zertifikat zu importieren.";
$l["smimeCert"]="SMIME-Zertifikat";
$l["sign"]="Signieren mit SMIME";
$l["encrypt"]="Verschlüsseln mit SMIME";
$l["settings"]="SMIME";
$l["deleteCert"]="Zertifikat löschen";
$l["selectPkcs12Cert"]="Neues PKCS12-Zertifikat auswählen";
$l["alwaysSign"]='E-Mails immer signieren';
$l["pkcs12Cert"]="PKCS12-Zertifikat";
$l["pkcs12CertInfo"]="Um ein neues PCSK12-Zertifikat hochzuladen, müssen Sie Ihr {product_name}-Kennwort eingeben. Dieses Kennwort muß sich aufgrund von Sicherheitsrichtlinien vom PCSK12-Schlüsselkennwort unterscheiden. Ein leeres Kennwort ist ebenso nicht zugelassen.";
$l["pubCerts"]="Öffentliche SMIME-Zertifikate";
$l["youHaveAcert"]='Sie haben bereits ein Zertifikat hochgeladen. SMIME-Unterstützung ist für diesen Account aktiviert.';
$l["downloadCert"]='Zertifikat herunterladen';
$l['name']='SMIME Unterstützung';
$l['description']='Erweitert das E-Mailmodul mit SMIME-Signatur und -Verschlüsselung';
$l['noPublicCertForEncrypt']="E-Mail kann nicht verschlüsselt werden, da Sie nicht über das öffentliche Zertifikat für %s verfügen. Öffnen Sie eine signierte E-Mail des Empfängers und überprüfen und installieren Sie das Zertifikat.";
$l['noPrivateKeyForDecrypt']="Diese E-Mail ist verschlüsselt jedoch verfügen Sie nicht über den privaten Schlüssel, um die E-Mail zu entschlüsseln.";
$l['badGoLogin']="Das {product_name}-Kennwort war nicht korrekt.";
$l['smime_pass_matches_go']="Ihr SMIME-Schlüsselkennwort entspricht Ihrem {product_name}-Kennwort. Dies widerspricht den Sicherheitsrichtlinien!";
$l['smime_pass_empty']="Ihr SMIME-Schlüssel ist nicht durch ein Kennwort geschützt. Dies widerspricht den Sicherheitsrichtlinien!";
$l['invalidCert']="Das Zertifikat ist ungültig!";
$l['validCert']="Gültiges Zertifikat";
$l['certEmailMismatch']="Gültiges Zertifikat, aber die Absenderadresse stimmt nicht mit der E-Mailadresse des Zertifikates überein.";
$l['decryptionFailed']='SMIME-Entschlüsselung dieser Nachricht fehlgeschlagen.';
